@@ -291,10 +291,16 @@ class IrrepsArray:
         jnp = _infer_backend(self.array)
 
         if isinstance(other, IrrepsArray):
-            if self.irreps.lmax > 0 and other.irreps.lmax > 0:
+            if self.irreps.num_irreps != other.irreps.num_irreps:
                 raise ValueError(
-                    "x * y with both x and y non scalar and ambiguous. "
-                    "Use e3nn.elementwise_tensor_product or e3nn.tensor_product instead."
+                    f"IrrepsArray({self.irreps}) * IrrepsArray({other.irreps}) only works if the number of irreps is the same."
+                )
+            irreps_out = e3nn.elementwise_tensor_product(self.irreps, other.irreps)
+            if irreps_out.num_irreps != self.irreps.num_irreps:
+                raise ValueError(
+                    f"IrrepsArray({self.irreps}) * IrrepsArray({other.irreps}) "
+                    "is only supported for scalar * irreps and irreps * scalar. "
+                    "To perform irreps * irreps use e3nn.elementwise_tensor_product or e3nn.tensor_product."
                 )
             return e3nn.elementwise_tensor_product(self, other)
 
@@ -535,22 +541,30 @@ class IrrepsArray:
         """
         return self.sorted().simplify()
 
-    def filter(self, keep_ir: Union[e3nn.Irreps, List[e3nn.Irrep], Callable[[e3nn.MulIrrep], bool]]) -> "IrrepsArray":
+    def filter(
+        self,
+        keep: Union[e3nn.Irreps, List[e3nn.Irrep], Callable[[e3nn.MulIrrep], bool]] = None,
+        *,
+        drop: Union[e3nn.Irreps, List[e3nn.Irrep], Callable[[e3nn.MulIrrep], bool]] = None,
+    ) -> "IrrepsArray":
         r"""Filter the irreps.
 
         Args:
-            keep_ir (Irreps or list of `Irrep` or function): list of irrep to keep
+            keep (Irreps or list of `Irrep` or function): list of irrep to keep
+            exclude (Irreps or list of `Irrep` or function): list of irrep to exclude
 
         Example:
             >>> IrrepsArray("0e + 2x1o + 2x0e", jnp.arange(9)).filtered(["1o"])
             2x1o [1 2 3 4 5 6]
         """
-        if keep_ir is None:
+        if keep is None and drop is None:
             return self
+        if keep is not None and drop is not None:
+            raise ValueError("Cannot specify both keep and drop")
 
-        irreps = self.irreps.filter(keep_ir)
+        new_irreps = self.irreps.filter(keep=keep, drop=drop)
         return IrrepsArray.from_list(
-            irreps, [x for x, mul_ir in zip(self.list, self.irreps) if mul_ir in irreps], self.shape[:-1]
+            new_irreps, [x for x, mul_ir in zip(self.list, self.irreps) if mul_ir in new_irreps], self.shape[:-1]
         )
 
     filtered = filter
@@ -594,7 +608,7 @@ class IrrepsArray:
         axis = _standardize_axis(axis, self.ndim)[0]
         jnp = _infer_backend(self.array)
 
-        new_irreps = (self.shape[axis] * self.irreps).simplify()
+        new_irreps = self.irreps.repeat(self.shape[axis]).simplify()
         new_array = jnp.moveaxis(self.array, axis, -2)
         new_array = jnp.reshape(new_array, self.shape[:-2] + (new_irreps.dim,))
         return IrrepsArray(new_irreps, new_array)
@@ -631,7 +645,7 @@ class IrrepsArray:
             factor = functools.reduce(math.gcd, (mul for mul, _ in self.irreps))
 
         if not all(mul % factor == 0 for mul, _ in self.irreps):
-            raise ValueError(f"factor {factor} does not divide all multiplicities")
+            raise ValueError(f"factor {factor} does not divide all multiplicities: {self.irreps}")
 
         irreps = Irreps([(mul // factor, ir) for mul, ir in self.irreps])
         new_list = [
