@@ -8,7 +8,9 @@ key = jax.random.PRNGKey(0)
 
 
 @pytest.mark.parametrize("quadrature", ["soft", "gausslegendre"])
-def test_s2grid_transforms(quadrature):
+@pytest.mark.parametrize("fft_to", [False, True])
+@pytest.mark.parametrize("fft_from", [False, True])
+def test_s2grid_transforms(quadrature, fft_to, fft_from):
     assert quadrature in ["soft", "gausslegendre"], "quadrature must be 'soft' or 'gausslegendre"
     res_alpha = 51
     res_beta = 30
@@ -20,8 +22,8 @@ def test_s2grid_transforms(quadrature):
     irreps = Irreps([(1, (l, p_val * p_arg**l)) for l in range(lmax + 1)])
     irreps_in = IrrepsArray(irreps, c)
 
-    res = to_s2grid(irreps_in, (res_beta, res_alpha), quadrature=quadrature)
-    irreps_out = from_s2grid(res, lmax, quadrature=quadrature, p_val=1, p_arg=-1)
+    res = to_s2grid(irreps_in, (res_beta, res_alpha), quadrature=quadrature, fft=fft_to)
+    irreps_out = from_s2grid(res, lmax, quadrature=quadrature, fft=fft_from)
     np.testing.assert_allclose(c, irreps_out.array, rtol=1e-5, atol=1e-5)
     assert irreps_in.irreps == irreps_out.irreps
 
